Python Client for Google Cloud Natural Language
===============================================

    Python idiomatic client for `Google Cloud Natural Language`_

.. _Google Cloud Natural Language: https://cloud.google.com/natural-language/

|pypi| |versions|

-  `Documentation`_

.. _Documentation: https://googlecloudplatform.github.io/google-cloud-python/stable/language-usage.html

Quick Start
-----------

.. code-block:: console

    $ pip install --upgrade google-cloud-language
    $ # OR
    $ pip install --upgrade google-cloud-natural-language

Authentication
--------------

With ``google-cloud-python`` we try to make authentication as painless as
possible. Check out the `Authentication section`_ in our documentation to
learn more. You may also find the `authentication document`_ shared by all
the ``google-cloud-*`` libraries to be helpful.

.. _Authentication section: http://google-cloud-python.readthedocs.io/en/latest/google-cloud-auth.html
.. _authentication document: https://github.com/GoogleCloudPlatform/gcloud-common/tree/master/authentication

Using the API
-------------

The Google Cloud `Natural Language`_ API (`Natural Language API docs`_)
provides natural language understanding technologies to developers,
including sentiment analysis, entity recognition, and syntax analysis.
This API is part of the larger Cloud Machine Learning API.

.. _Natural Language: https://cloud.google.com/natural-language/
.. _Natural Language API docs: https://cloud.google.com/natural-language/reference/rest/

See the ``google-cloud-python`` API Natural Language `Documentation`_ to learn
how to analyze text with this API.

.. |pypi| image:: https://img.shields.io/pypi/v/google-cloud-language.svg
   :target: https://pypi.python.org/pypi/google-cloud-language
.. |versions| image:: https://img.shields.io/pypi/pyversions/google-cloud-language.svg
   :target: https://pypi.python.org/pypi/google-cloud-language
